@@ -19,20 +19,13 @@
  *                                                                         *
  ***************************************************************************/
 
-/*#define DEBUG*/
 
 #ifndef BRUCH_H
 #define BRUCH_H
 
-/* for the I18N_NOOP macro */
-#include <klocale.h>
-
 #include "Task.h"
 #include "AppMenuWidget.h"
 
-static const char description[] =
-    I18N_NOOP("KBruch");
-
 class Task;
 
 #endif /* ifndef BRUCH_H */
